#
# spec file for package adwaita-icon-theme
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           adwaita-icon-theme
Version:        47.0
Release:        1.1
Summary:        GNOME Icon Theme
License:        CC-BY-SA-3.0 OR LGPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/adwaita-icon-theme
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-loader-rsvg
BuildRequires:  gtk3-tools >= 3.24.2
BuildRequires:  meson >= 0.64.0
BuildRequires:  pkgconfig
# To make sure the icon theme cache gets generated
Requires(post): (gtk3-tools if libgtk-3-0)
Requires(post): (gtk4-tools if libgtk-4-1)
Provides:       %{name}-devel = %{version}-%{release}
BuildArch:      noarch

%description
The default GNOME icon theme, Adwaita.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
# Those folders disappeared in the upgrade from 2.28.0 -> 2.29.0
# FIXME: eventually no application should install any files there
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/actions
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/apps
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/categories
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/devices
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/emblems
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/emotes
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/mimetypes
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/places
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/status
mkdir -p %{buildroot}%{_datadir}/icons/Adwaita/scalable/stock/generic
# Add internet-web-browser symlink (to web-browser) to adwaita-icon-theme (bnc#767437)
for folder in %{buildroot}%{_datadir}/icons/Adwaita/*x[0-9]*; do
 ln ${folder}/apps/web-browser.png ${folder}/apps/internet-web-browser.png || :
done
%{icon_theme_cache_create_ghost Adwaita}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING COPYING_LGPL COPYING_CCBYSA3
%doc AUTHORS NEWS
%ghost %{_datadir}/icons/Adwaita/icon-theme.cache
%{_datadir}/icons/Adwaita/
%{_datadir}/pkgconfig/adwaita-icon-theme.pc

%changelog
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + cursors: updated spinners to match libadwaita.
* Mon May 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + inherit from AdwaitaLegacy.
  + symbolic: mic icons -- more opaque and legible in shell's top
    bar.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Stable release: no changes since 46.rc.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + cursors: fix windows build.
  + cursors: reinstate some x11 cursor names.
  + symbolic: thunderbolt, phone & export fixes.
  + index.theme: remove duplicate entries .
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta+6:
  + build: Reinstate symlinks from X11 cursor names to closest CSS
    names.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + cursors: clean up shapes, sync DND metaphors with macos.
  + symbolic: revert about metaphor.
  + symbolic: shared screen metaphor update.
* Tue Jan 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Create symlinks for hand2, xterm and left_ptr cursors
  (glgo#GNOME/adwaita-icon-theme#274).
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + fullcolor: antialias 16x16 a little more.
  + symbolic: replace filled silhouettes with outlines.
  + cursors: only cover the CSS named.
  + symbolic: help-about metaphor.
  + symbolic: sync not-junk metaphor.
  + symbolic: cleaned up export with Symbolic Preview.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + No changes from 45.rc, stable versionbump only.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.rc:
  + cursors: new hand cursors, updated spinner.
* Sat Jul  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + New meson build system
  + fullcolor: new audio mimetype
  + symbolic:
  - notifications in outline style
  - go home, user-home, notifications in outline style
  - new weather icons
  + cursors: tooling in python 3
- Add meson BuildRequires and macros following upstreams port.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Stable version bump only.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Fullcolor:
  - Use scalables instead of large bitmaps, using the app icon
    toolchain.
  - Low res only at 16x16, lean onto the scalables for everything
    else.
  + symbolic: updated rounded style.
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43:
  + No changes, stable bump only.
* Fri Aug 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.beta.1:
  + build: fix dist tarball creation (symlink issue).
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Fix build
  + fullcolor:
  - drag accept gradient
  - fix trash transparency
  + inkscape 1.2 compatibility
  + symbolic:
  - auth-face for face unlock
  - bluetooth off
  - folder icons
  - modem updates
  - package icons
  - restore
  - revert RTL changes for media seek
  - selection-mode tweaks
  - starred updates
  - update style to the contemporary rounded outlines
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + symbolic: provide -rtl versions properly.
  + README: bring up to date.
  + fullcolor: fix input-mouse.
* Mon Feb 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace Requires(post): gtk3-tools with the 2 following:
  + Requires(post): (gtk3-tools if libgtk-3-0)
  + Requires(post): (gtk4-tools if libgtk-4-1)
  Do this as we want gtk3-tools when building and installing a gtk3
  based package, and gtk4-tools when building and installing a gtk4
  based package.
* Wed Feb 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Symbolic:
  - Port over to core.svg for new toolchain (Symbolic Preview).
  - Updated style across the board - simpler, rounder,
    consistently 2px thick outlines.
  + Fullcolor:
  - Prune legacy fullcolor lowres, apps like Evolution ship their
    assets from now on.
  - Updated device icons.
  - Updated folder icons.
* Mon Sep 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0:
  + fullcolor network server and workgroup.
  + symbolic: larger symbolics for headerbar.
  + symbolic: larger notification.
  + updated guidelines.
  + symbolic: ascend/descending sort.
  + symbolic: edit-clear-all new metaphor.
  + fullcolor: application-x-addon and application-x-firmware.
* Tue May  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1.1:
  + symblic: night-light bbox fix.
* Mon May  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + 5G cellular status.
  + night light legibility.
  + hicolor inheritance.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + No changes compared to 40.rc.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Fullcolor emblem contrast.
  + Cursor naming.
  + symbolic: bluetooth-disconneted, power profile icons, night
    light and display brightnessn, and contact-new.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + No changes.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + inkscape 1.0 based rendering.
  + build system fixes.
  + fullcolor: removable media.
  + remove legacy fullcolor weather icons.
- Changes from version 3.37.2:
  + symbolic: night light metaphor.
  + symbolic: larger expanders.
  + scripts -- rendrable with inkscape 1.0.
* Fri Apr 17 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Symbolic:
  - User-not-tracked bugfix.
  - Color coding of battery states.
  - Hw disabled states.
  - Microphone state icons.
  + Fullcolor: video-x-generic metaphor.
- Switch back to tarball release. Following this, drop libtool
  BuildRequires and autogen call, no longer needed.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Symbolic:
  - Media rtl cleanup.
  - Night light more identifiable.
* Fri Feb 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.35.92:
  + Fullcolor mimetype icons - firmware, addons for they are
    prominently exposed in Software.
  + Drop rtl variant for playback.
- Use explicit commitid as upstream borked the tag and tarball.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Updated icon set.
* Tue Nov 26 2019 Frederic Crozat <fcrozat@suse.com>
- Ensure we have a recent enough version of gtk3-tools to build
  the package.
* Fri Nov  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Fullcolor: trash icons.
  + Symbolic:
  - rotation lock.
  - battery icons.
- Changes from version 3.34.2:
  + Fullcolor: visible folder-documents.
* Mon Nov  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Symbolic:
  - propegate the checkmark refinements.
  - slightly smaller media-eject.
  - centre alignment for go-next/previous.
  - add ! to battery level 0.
  - missing classes for battery icons.
* Sat Oct 12 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+13:
  + Symbolic:
  - refined preferences-system-parental-controls
  - add preferences-system-parental-controls
  - fix missized copy icon; fix stroke in folder-new
  - view-more use circles
  - be less clever in the document icons
  - refine clear icons; retire brush metaphor for clear-all
  - refine alarm shape
- Switch to git checkout, explicit commit from master branch.
  Following this, add libtool BuildRequires and pass autogen.sh,
  needed to boostrap since we are now using a checkout.
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Fullcolor: update media-optical to the new style.
* Sat Sep  7 2019 luke@ljones.dev
- Update to version 3.33.92:
  + symbolic:
  - send-to metaphor.
  - battery-missing-symbolic.
  - pixel perfect question mark.
  - mail-attachment metrics.
  - view-reveal, view-conceal for passwords.
  - keyboard.
  - folders as inode.
  - orientation icons.
  - touch-disabled.
  - weather-tornado.
  - battery level icons.
  + fullcolor: colorful packages.
* Mon Mar 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + No changes, stable version update only.
* Tue Feb 19 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + symbolic:
  - folder-download, inode-directory
  - privacy, dnd, phone device icons
  - new ui context for things that aren't strictly icons. Might
    go into gtk
  - emoji category tweaks
  - mail-reply, battery status
  - action icons eg rotation
  - drive icon tweaks
  + fullcolor:
  - more app/mimetype/device/status to legacy
  - new style for fullcolor icons - folders, mimetypes and
    devices
  + cursors: fix a symlink mixup.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + few symbolic updates
  + move a lot of fullcolor icons to legacy context. They will go
    or be updated in 2 releases.
  - symbolic: lists
  - fullcolor: more app, device, mimetypes to legacy
* Tue Nov 20 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix nasty misrendering of inode-directory-symbolic.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + audio-speakers-symbolic rendering glitch
    (glgo#GNOME/adwaita-icon-theme#11).
  + *starred-symbolic 2px outline as per guidelines
    (glgo#GNOME/adwaita-icon-theme#7).
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Symbolic fingerprint, smartcard reader devices.
  + Emoji category icons in symbolic form.
  + Render script improvements.
  + General cleanup and maintenance.
  + SIM status icons (symbolic).
  + System-log-out-symbolic.
  + Screen sharing status.
  + Thicked strokes for *starred-symbolic.
  + Iput-gaming and application-games consistent.
  + Bluetooth rendering fix.
  + Application-x-appliance alignment.
  + Tab-new, application-x-executable improvements.
  + User-bookmarks metaphor.
  + General grid alignment fixes.
  + SVG filesize optimalizations.
- Use autosetup macro.
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + No visible changes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb  8 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Camera-switch-symbolic (bgo#750285).
  + Highres sizing issue (bgo#785574).
  + Vpn-noroute.
  + Optional zopfli png optimizer.
  + Audio-volume-* fuzzy (bgo#709131).
  + Audio-volume-overamplified.
  + New metaphors for settings -- notifications, volume and
    privacy.
- Drop unneeded %%icon_theme_cache_post posttrans scriptlet: it's
  no longer needed since RPM File Triggers.
* Mon Nov 27 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Fix scalability issues with 256/512 size (bgo#785574).
  + Audio-volume-* pixel alignment.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Drop adwaita-symbolic-audio-volume-fix.patch: fixed upstream.
- Drop intltool BuildRequires as there are no translations to deal
  with in the package.
* Sat Nov 18 2017 zaitor@opensuse.org
- Add adwaita-symbolic-audio-volume-fix.patch: symbolic:
  audio-volume-*: line up vertices to the pixel grid (bgo#709131).
* Thu Sep 14 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Thunderbolt status icons.
  + System settings icons.
* Thu Aug 24 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updates and fixes to symbolic icons.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.24.4:
  + Symbolic firmware and device icon.
  + Form validation error icon (symbolic).
  + Fullcolor emblem fixes.
  + Symbolic icon for pinning views.
- Drop obsolete clean section.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Visual Studio build fixes.
  + Bringing back system-file-manager generic icon.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91.1:
  + Fullcolor image icons.
  + Image-loading.
  + Sunsize, sunset symbolic icons.
  + Natural-light-filter for symbolic.
* Wed Feb 22 2017 dimstar@opensuse.org
- Move %%icon_theme_cache_post from post to posttrans: in case of
  an update, at the time the post script of the new package is
  being executed, the files of the old package are still on disk.
  If the new version now removes some files (meaning the files
  disappear on disk once rpm uninstalls the old version), we still
  have a cache in place referencing those old icons. This can lead
  to situations where several apps simply fail to load their icon.
* Wed Feb  1 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Refresh icon set.
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Simplified input-table-symbolic.
  + Opacity fixes for networking-vpn-acquring.
  + Invisible go-down-symbolic.
* Fri Sep  2 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + User-available-symbolic transparency fix.
  + Calculator app icon update.
  + Fixed cursors.
  + Folder-download-symbolic style fixes.
  + Vertical visual centering for go-up, go-down-symbolic icons.
* Sat May 28 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Network-wireless-connected improvements.
  + Document-edit, text-editor, modem-symbolic shape improvement.
  + Baseline-align folders.
  + Reshape folders.
  + Add a context-menu cursor.
  + Improve grab and dnd-no-drop cursors.
- Drop adwaita-symbolic-fixes.patch: Fixed upstream.
* Fri May 27 2016 dimstar@opensuse.org
- Actually apply adwaita-symbolic-fixes.patch.
* Fri May 27 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Thu Apr 21 2016 zaitor@opensuse.org
- Add adwaita-symbolic-fixes.patch: Add two upstream commits fixing
  symbolic icons.
* Tue Mar 22 2016 zaitor@opensuse.org
- Update to version 3.20:
  + Win32 build fixes.
* Thu Mar  3 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Add application-x-addon-symbolic.
  + Win32 build fixes.
  + Win32 grey shadows fixed (bgo#763034).
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Lighter fullcolor folders.
  + Thicker stroke for non-starred-symbolic.
  + Emblem-new metaphor sync.
  + Call-start call-stop symbolic shape improvements.
  + Mark-location-symbolic improved shape.
  + Edit-cut shape improvement.
  + Simplify hdd symbolic shapes.
  + Document-edit-symblic.
  + Visual separation between list and grid view and hamburger menu
    (symbolic).
  + Symbolic wifi-acquiring bugfix.
  + Specfic icon grid for gnome-shell.
  + Windows build system scripts.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Improved view-list-symbolic.
  + Cursors working on KDE.
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Updated folder-new-symbolic.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Updated cursors, support for win32.
  + Address-book-new fix.
  + Ebook device icon.
  + Updated select-all metaphor.
  + Removed widget assets form and icon theme.
  + Privacy-mode symbolic icon.
  + Intltool fixes.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2.1:
  + Updated translations.
- Changes from version 3.16.2:
  + Better metaphor for rotation allowed (bgo#747117).
  + Preferences-desktop-font for font-viewer.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Fri Mar 20 2015 zaitor@opensuse.org
- Update to version 3.15.92:
  + Symbolic application-system.
  + a11y icons for shell (bgo#746022).
  + Generic firmware mimetype icon.
* Wed Feb 11 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Image manipulation action icons for symbolic (Photos).
  + Less bulky folders.
  + Fullcolor mark location.
  + Grid alignment for some symbolics.
  + Updated translations.
- Drop adwaita-icon-theme-rpmlintrc: the rpmlint is no longer
  present, since we do not obsolete gnome-icon-themes anymore.
* Mon Jan 26 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + No hard dep on gtk-update-icon-cache (bgo#739290).
  + Missing icons needed for HC theme (bgo#732511).
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 29 2014 dimstar@opensuse.org
- Do not obsolete gnome-icon-theme, gnome-icon-theme-extras and
  gnome-icon-theme-symbolic: a lot of non-GNOME package depend more
  or less correct on those theme names, mostly to 'cheat' and not
  having to bring own icon themes.
* Tue Sep 23 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix grid alignment in some symbolics.
  + Sync folder-videos and folder-videos-symbolic.
  + Updated ranslations.
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Checkbox/radio assets for gtk part of the symbolic icon theme.
  + Updated cursors. 16 frame animation for fluidity (bgo#734429).
  + Grid alignment for dictionary.
  + Highres input-gaming (bgo#735160).
  + Cellular network status cleanup (bgo#735236).
  + Rrtl variants for media icons (bgo#735721).
  + Floating point errors in dimensions (bgo#634023).
  + Updated translations.
* Fri Aug 22 2014 dimstar@opensuse.org
- Update to version 3.13.5:
  + Support pre-rendered symbolic pngs.
  + Improved cursors.
  + Add missing symbolic mimetype icons.
  + Updated translations.
- Add gdk-pixbuf-loader-rsvg BuildRequires: due to possible cycles
  the RSVG loader is split out of the regular gdk-pixbuf and we
  have to require it explicitly here.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Add open-menu-symbolic.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Symbolic icons for use in gtk theme instead of image assets.
  + Spinner that only scales up to 32.
  + Naming fixes.
  + Sync metaphors between fullcolor and symbolic.
  + Fix a few misrendering of symbolic icons.
- Changes from version 3.13.2:
  + Checkbox and radio as icons (for popovers and menus in gtk).
  + Dropped legacy icon name mapping using symlinks (bgo#728984).
  + Generic document-new (simple scan).
  + Spinner as icon (process-working).
  + Updated folder design for hicolor.
  + Expanders as icons (bgo#729565).
  + Settings for high contrast (bgo#708311).
  + Updated translations.
- Changes from version 3.13.1:
  + Make a/c status more prominnet (bgo#701031).
  + Combine fullcolor, symbolic & cursor assets into one module.
- Rename package from gnome-icon-theme to adwaita-icon-theme,
  following upstreams:
  + Obsolete gnome-icon-theme, gnome-icon-theme-extras and
    gnome-icon-theme-symbolic: they have been merged into one (no
    provides, as the icon path is different, so it is not a 100%%
    drop-in replacement).
- Drop hicolor-icon-theme and icon-naming-utils-devel
  BuildRequires: no longer required.
- Add rpmlintrc: the provides is intentionally not accompanied by
  an obsoletes.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Stable release, no changes since 3.11.92.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Semi starred icon (bgo#689098).
  + Better fir for Files and save/open icons.
  + Addon and repositories icons (bgo#724669).
* Thu Feb  6 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Scale gedit properly.
  + media-player cleanup.
  + Make folder-download emblem more legible.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Build fixes.
* Wed Jul 31 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Color shift for folder (bgo#700757).
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Heaphones & headset.
  + Notifications panel updated.
  + Make folders a tad less prominent again.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + system-shutdown.
  + scale icons to fit canvas better (bgo#694279).
  + beige folders.
  + emblem centering (bgo#695523).
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Rendering tweaks
  + network-cellular-connected.
* Thu Jan 17 2013 zaitor@opensuse.org
- Update to version 3.7.4:
  + preferences-system-sharing: For sharing settings.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Add icons for new panels: search, notifications, privacy.
  + Add icons for RAID and other multidisk devices.
  + Weather icons.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Stable release: No changes compared to 3.5.90.
* Thu Aug 23 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + No actual changes. Only a re-release for 3.5.90.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Update IM status icons to sync with -symbolic.
* Wed Jun 20 2012 dimstar@opensuse.org
- Add internet-web-browser symlink to web-browser (bnc#767437).
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + No changes.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + trophies icons
  + UPS icon
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Oct 20 2011 vuntz@opensuse.org
- Update to version 3.2.1.2:
  + Re-release of 3.2.1.1.
* Wed Oct 19 2011 dimstar@opensuse.org
- Update to version 3.2.1.1:
  + Fix media-playback-start icon being rtl by default [bgo#662171]
* Tue Oct 18 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + right to left variants of directional icons.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + just adding numbers :)
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + updated wallpaper icon
  + removable media icon
  + updated user status icons
  + dialpad icon
* Fri Jul 22 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + printer-network
  + starred/unstarred status
  + window decoration icons updated to current look (bgo#650712)
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + prepare for awesome
  + camera-web highres
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + volume icon in highres
  + mouse device icon redone + highres
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + 'fail whale'
  + disconnected wired network
  + vpn 'device'
  + development
  + scanner
  + dialog-password in highres
* Fri Feb 25 2011 fcrozat@novell.com
- Update to version 2.91.7:
  + Speaker device icon
- Changes from version 2.91.6:
  + Include license files in tarball
  + Updated translations
- Add gtk3-tools Requires(post) because we want to make sure the
  icon theme cache is generated.
* Thu Dec 23 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + generic phone device
  + metadata cleanup
  + blank template for new icons
  + generic tablet in highres
  + system-run in high res
  + microphone input level icons
  + regenerate cache during installation
  + video-camera in highres
  + folder for preview (bgo#635612)
* Wed Aug 25 2010 vuntz@opensuse.org
- Add hicolor-icon-theme BuildRequires.
- Use the %%icon_theme_cache_* macros to make sure the icon theme
  cache is created/updated.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.0:
  + relicensed to GNU LGPL v3 or Creative Commons BY-SA 3.0
  + highres icon additions
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.30.3:
  + bgo#618021: add high resolution volume icons.
* Mon May  3 2010 dimstar@opensuse.org
- Update to version 2.30.2.1:
  + bgo#616954: revert filename change for mail-mark-not(-)junk.
  + remove old ruby render script
  + build system fixes.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.2:
  + tweaks to edit-delete
  + publicshare folder to use same metaphor as emblem-shared
  + new icon avatar-default to replace stock_person
  + remove media-zip and jaz.
  + bgo#616325: lighten up displays and computers
- Changes from version 2.30.1
  + re-add mail icons
  + sharper print preview icons
  + remove shadows form some 16x16s
  + bgo#615194: re-add text-x-preview (no clipping rectangle
    though)
  + nautilus app icon fixes
  + new edit-delete metaphor.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Remove arrows from format-justify-*
  + Updated translations.
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 2.29.3:
  + --enable-icon-mapping works
  + edit-find and edit-find-replace finetuned
  + redundant system-search tweaked rather than dropped for now
* Sun Mar  7 2010 dimstar@opensuse.org
- Create the folder structure in icons/gnome/scalable.
* Thu Mar  4 2010 dimstar@opensuse.org
- Update to version 2.29.2
  + bugfix: misplaced process-working
- Changes from version 2.29.1
  + bgo#606245: added .pc file back
  + missing emoticons
  + accessories-dictionary at 24x24px
  + highres web-browser
  + bgo#611480: changes-prevent and changes-allow to replace
    stock-lock icons.
  + progress-working from 2.28
- Drop gnome-icon-theme-pc.patch, upstream fixed.
* Fri Feb 26 2010 dimstar@opensuse.org
- Update to version 2.29.0
- Add gnome-icon-theme-pc.patch to bring the .pc file back until
  other depending applications don't use it anymore (or it's
  upstream decided to really keep it). See bgo#606245.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
- Drop gnome-icon-theme-example-icon.patch, upstream fixed.
* Fri Aug 14 2009 vuntz@novell.com
- Really apply gnome-icon-theme-example-icon.patch.
* Thu Aug 13 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Updated translations.
* Tue May 12 2009 vuntz@novell.com
- Add gnome-icon-theme-example-icon.patch to fix the icon
  thumbnailed in the appearance capplet.
- Remove AutoReqProv: it's default now.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Updated translations.
- Add BuildRequires on pkg-config to fix build.
* Sat Mar 14 2009 vuntz@novell.com
- Update to version 2.25.92:
  + Removed some duplicate icons that are old style.
  + Add a 48x48 of the new process-working icon.
- Stop shipping a 48x48 version of system-search: it's available
  in scalable anyway. If it's really needed, then we should file a
  bug upstream.
* Tue Feb 24 2009 vuntz@novell.com
- Remove glib2-devel BuildRequires.
- Don't package empty README.
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.91:
  + Cosmetic version bump
- Remove perl-XML-Parser and gnome-common from BuildRequires
* Wed Feb 11 2009 vuntz@novell.com
- Update to version 2.25.90:
  + process-working: replace the spinner. (bgo#558367)
* Wed Oct  1 2008 mboman@suse.de
- Update to version 2.24.0:
  + Cosmetic version bump
* Tue Sep 16 2008 mboman@novell.com
- Update to version 2.23.92:
  + Changed the metaphor of the accessibility icon as requested by the a11y
    team
* Sun Aug 31 2008 mboman@novell.com
- Update to version 2.23.91:
  + Cosmetic version bump
* Sun Aug 24 2008 mboman@novell.com
- Update to version 2.23.90:
  * {16x16,22x22,24x24,32x32,scalable}/places/user-bookmarks.png:
    added user-bookmarks icon based on bookmark-new
  * scalable/places/Makefile.am: Fixed typo that broke the
    build: user-bookmark should be user-bookmarks.
* Sat Aug  9 2008 captain.magnus@opensuse.org
- Update to version 2.23.3:
  + {32x32,48x48}/actions/zoom* : little refresh for a more consistent look.
  + 48x48/apps/Makefile.am:
  + 48x48/apps/gnome-settings-default-applications.png:
    Remove this icon which is no longer needed
    Fixes bgo#538474
  + configure.in:
    Fix the help text for icon-mapping to say auto instead of $mapenable
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.23.2:
  + Changes to improve Consistency
  + Drop old icons.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Cosmetic version bump
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + New and improved icons.
* Wed Jan 30 2008 maw@suse.de
- Update to version 2.21.4:
  + New icons.
* Tue Sep 18 2007 sbrabec@suse.cz
- Update to version 2.20.0:
  * remove gnome-logout file as it is replaced by system-log-out
  * add missing directories for emotes
  * fix emblem anchors to match the ones folder.icon
* Fri Aug 31 2007 maw@suse.de
- Add a system-search.png icon sized 48x48.
* Wed Aug 29 2007 maw@suse.de
- Update to version 2.19.91
- Bugs (bugzilla.gnome.org) fixed: #470260, #470391, #470249,
  [#468035], #361158, #467814, #370032, and #453611
- Use %%fdupes.
* Fri May  4 2007 pgajdos@suse.cz
- removed hicolor-icon-theme from BuildRequires [#247450]
* Thu Mar 22 2007 dobey@suse.de
- Update version to 2.18.0
- Remove the old-style gnome-dev-ethernet icons
- Remove the unneeded hicolor_dirs variable in make install
* Mon Feb 26 2007 stbinner@suse.de
- Require hicolor-icon-theme to fix several apps build
* Wed Feb 21 2007 dobey@suse.de
- Split out hicolor-icon-theme to its own package
  Remove unused realplay.png
* Mon Feb 19 2007 maw@suse.de
- Updat to version 2.17.91.
* Wed Jan  3 2007 sbrabec@suse.cz
- More spec file cleanups.
* Thu Dec 14 2006 maw@suse.de
- Move to /usr
- Some specfile cleanup.
* Tue Oct 17 2006 jhargadon@suse.de
- update to version 2.16.0.1
- Updated system-lock-screen icon to fill all sizes - bug #354257
- Updated accessories-text-editor icon to fill all sizes - bug #354256
- Updated 24x24 utilities-terminal icon from 22x22 icon - bug #354279
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0
- Add gtk-edit icon at 16x16, 22x22, and 24x24 sizes
- Install 24x24 video-display icon
- Update 24x24 computer icon from updated 22x22 source
- Add a new logviewer icon
- New help-browser, emblem-new, and user-desktop icons
- New text-x-generic-template icon
- Add scalable and 32x32 go action icons
- Updated scalable and 32x32 go-home icons
- New list-add and list-remove icons
- Port some cvs emblem icons to scalable
- Replace emblem-package and emblem-web with new style icons
- Add missing 32x32 mimetypes directory to index.theme.in
- Updated network status icons
- New translations [mg, mr]
* Thu Aug 24 2006 jhargadon@suse.de
- update to version 2.15.92
- Add x-office-drawing icon
- Add 32x32 mime type icons
- Update scalable mime type icon shadows
- Add application-certificate icon
- More icon cleanup to remove replaced icons
- Add zoom-best-fit icon
- Add 32x32 and scalable folder-new icons
- Fix scalable web-browser icon not being installed
- 32x32 versions of zoom icons
- Updated style weather status icons
- 32x32 and scalable applications-development icons
- Updated translations
* Mon Aug 21 2006 jhargadon@suse.de
- update to version 2.15.90
- Moved stock_* fullscreen icons to view-* action names
- Many new icons
- Add document-new icons and update new "emblem" on *-new icons
- New preferences-desktop-screensaver and system-file-manager
- updated translations
- New printer device and print action icons
- Add in spinner animations to replace gnome-spinner images
- Update scalable folders to match the pixmaps better
- Replace gnome-fs-regular with text-x-preview
* Mon Apr 10 2006 dobey@suse.de
- Add patch to make the sizes for scalable icons more sane
  Mostly fixes https://bugzilla.novell.com/show_bug.cgi?id=162222
* Mon Apr  3 2006 dobey@suse.de
- Update hicolor-icon-theme tarball to 0.9 for multiple bug fixes
* Sat Mar  4 2006 aj@suse.de
- Fix typo in last change.
* Thu Mar  2 2006 dobey@suse.de
- Remove gaim icon from gnome-icon-theme
  Fixes part of https://bugzilla.novell.com/show_bug.cgi?id=153748
* Tue Feb 28 2006 dobey@suse.de
- Remove extra hicolor-icons.tar.bz2 per request from coolo
* Wed Feb 15 2006 dobey@suse.de
- Create 24x24/apps and 24x24/mimetypes directories in hicolor
  These directories are needed for some apps to install icons to
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 13 2005 sbrabec@suse.cz
- Minimized neededforbuild.
* Tue Oct 11 2005 gekker@suse.de
- Update to version 2.12.1
- Fixes configuration problem (#91387)
- Remove upstreamed patches
* Fri Sep 16 2005 sbrabec@suse.cz
- Call aclocal to build properly in PLUS.
* Tue Sep 13 2005 sbrabec@suse.cz
- Build as NoArch.
* Tue Sep 13 2005 sbrabec@suse.cz
- Reset executable flag for icons (#116346).
* Mon Sep  5 2005 rodrigo@suse.de
- Update to version 2.12.0
* Mon Aug 22 2005 gekker@suse.de
- Update to version 2.11.92
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.91
* Mon Aug  1 2005 gekker@suse.de
- Update to version 2.11.90
* Fri Jul 22 2005 gekker@suse.de
- Update to version 2.11.5
* Wed Mar 23 2005 clahey@suse.de
- Updated to version 2.10.1.  Adds Open Document icons.  Fixes 73536.
* Sat Mar 19 2005 clahey@suse.de
- Add icons for word docs and realplayer supported types.
* Wed Mar 16 2005 clahey@suse.de
- Use the gnome-dev-ethernet from netapplet.
* Tue Mar  8 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 2.9.92
* Fri Feb 11 2005 gekker@suse.de
- Update to version 2.9.91
* Sat Feb  5 2005 gekker@suse.de
- Update to version 2.9.90
* Wed Jan 19 2005 clahey@suse.de
- Updated to version 2.9.3.
* Thu Dec 16 2004 gekker@suse.de
- Update to version 2.9.2
* Tue Nov 23 2004 gekker@suse.de
- Update version to 2.9.1
  Remove wordperfect file / artwork as it was already upstream.
* Wed Sep 29 2004 hhetter@suse.de
- added essential icons for drives:/ operation to hicolor
* Mon Sep 27 2004 mmichael@suse.de
-  Add wordperfect file / artwork.
* Mon Sep 27 2004 sbrabec@suse.cz
- Removed old RealPlayer branding.
  http://bugzilla.gnome.org/show_bug.cgi?id=153677
* Wed Jul 28 2004 dobey@suse.de
- Updated to version 1.2.3
* Fri Apr 23 2004 sbrabec@suse.cz
- Updated to version 1.2.1 (GNOME 2.6).
- Added hicolor-icon-theme version 0.5.
* Wed Oct 29 2003 sbrabec@suse.cz
- Updated to version 1.1.0.
* Tue Sep  9 2003 sbrabec@suse.cz
- Updated to version 1.0.9.
* Mon Sep  8 2003 sbrabec@suse.cz
- Updated to version 1.0.8.
* Wed Aug 27 2003 sbrabec@suse.cz
- Updated to version 1.0.7.
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 1.0.6.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jul  9 2003 sbrabec@suse.cz
- Updated to version 1.0.5.
* Mon Jun 23 2003 ro@suse.de
- added gnome-filesystem to neededforbuild
* Fri Jan 31 2003 hhetter@suse.de
- updated to version 1.0.0
* Thu Jan 16 2003 sbrabec@suse.cz
- Fixed %%prefix to /opt/gnome2.
* Wed Jan 15 2003 sbrabec@suse.cz
- Added new package.
